@@ -590,6 +590,9 @@ impl Serializable for BwtBlock64AO {
         
         Ok(casted)
     }
+    fn size_of(&self) -> usize {
+        8 * (CHR_COUNT + BITS_COUNT)
+    }
 }
 
 #[repr(C)]
@@ -1012,4 +1015,7 @@ impl Serializable for BwtBlock128AO {
         
         Ok(casted)
     }
+    fn size_of(&self) -> usize {
+        8 * (CHR_COUNT + (2 * BITS_COUNT))
+    }
 }
