@@ -612,6 +612,9 @@ impl Serializable for BwtBlock64AN {
         
         Ok(casted)
     }
+    fn size_of(&self) -> usize {
+        8 * (CHR_COUNT + BITS_COUNT)
+    }
 }
 
 
@@ -1050,4 +1053,7 @@ impl Serializable for BwtBlock128AN {
         
         Ok(casted)
     }
+    fn size_of(&self) -> usize {
+        8 * (CHR_COUNT + (2 * BITS_COUNT))
+    }
 }
